--[[
FuelTrailerOverrides

Specialization to override the FuelTrailer.draw and FuelTrailer.load functions

Author:		Ifko[nator]
Version:	1.0
Date:		25.03.2015

History:	V 1.0 @ 25.03.2016 - intial release in FS 15
			V 2.0 @ 24.04.2016 - fix issues with  the maintrace trailer from vertex dezing
]]

FuelTrailerOverrides = {};

local currentModDirectory = g_currentModDirectory;

function FuelTrailerOverrides.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(FuelTrailer, specializations);
end;

function FuelTrailerOverrides:preLoad(xmlFile)
	FuelTrailer.draw = Utils.overwrittenFunction(FuelTrailer.draw, FuelTrailerOverrides.drawFuelTrailer);
	FuelTrailer.load = Utils.overwrittenFunction(FuelTrailer.load, FuelTrailerOverrides.fuelTrailerLoad);
end;

function FuelTrailerOverrides:fuelTrailerLoad(load, xmlFile)
	self.setIsFuelFilling = SpecializationUtil.callSpecializationsFunction("setIsFuelFilling");
    self.addFuelFillTrigger = FuelTrailer.addFuelFillTrigger;
    self.removeFuelFillTrigger = FuelTrailer.removeFuelFillTrigger;
    self.fuelTrailerFillActivatable = FuelTrailerFillActivatable:new(self);
    self.fuelFillTriggers = {};
    self.isFuelFilling = false;
    self.fuelFillLitersPerSecond = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.fuelFillLitersPerSecond"), 50);
    
	local gasStationTriggerNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.gasStationTrigger#index"));
    
	if gasStationTriggerNode ~= nil then
		if string.find(self.configFileName, "Kotte") then	
			self.gasStationTrigger = GasStationKottePack:new(gasStationTriggerNode, self);
		else
			self.gasStationTrigger = GasStation:new(gasStationTriggerNode, self);
		end;
    end;
    
    if self.isClient then
        self.sampleRefuel = Utils.loadSample(xmlFile, {}, "vehicle.refuelSound", "$data/maps/sounds/refuel.wav", self.baseDirectory, self.components[1].node);
	end;
end;

function FuelTrailerOverrides:drawFuelTrailer(draw)
	--## function is empty, to pre event from two 'first fill the tool' texts in the helpbox
end;

--## unused functions

function FuelTrailerOverrides:load(xmlFile)end;
function FuelTrailerOverrides:delete()end;
function FuelTrailerOverrides:mouseEvent(posX, posY, isDown, isUp, button)end;
function FuelTrailerOverrides:keyEvent(unicode, sym, modifier, isDown)end;
function FuelTrailerOverrides:update(dt)end;
function FuelTrailerOverrides:updateTick(dt)end;
function FuelTrailerOverrides:draw()end;